# Converts the output of some inspect functions to a DataFrame

## pip install a-pandas-ex-inspect2df


```python
    Convert the attributes of an object into a pandas DataFrame with information about each attribute.

    Args:
        obj: An object to inspect.

    Returns:
        A pandas DataFrame with the following columns:
            - aa_attrb_name: The name of the attribute.
            - aa_signature: The signature of the attribute.
            - aa_attrb: The attribute itself.
            - aa_doc: The docstring of the attribute.
            - aa_annotations: The annotations of the attribute.
            - aa_absfile: The absolute path of the file containing the attribute.
            - aa_closurevars: The closure variables of the attribute.
            - aa_unwrapped: The unwrapped attribute.

    Raises:
        None.
```


```python

from a_pandas_ex_inspect2df import inspect2df
import pandas as pd
print(inspect2df(pd)[:25].to_string(max_colwidth=30))
       aa_attrb_name                   aa_signature                       aa_attrb                         aa_doc                 aa_annotations                     aa_absfile aa_closurevars                   aa_unwrapped
0         ArrowDtype  (pyarrow_dtype: 'pa.DataTy...  <class 'pandas.core.arrays...  An ExtensionDtype for PyAr...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
1       BooleanDtype                             ()  <class 'pandas.core.arrays...  Extension dtype for boolea...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
2        Categorical  (values, categories=None, ...  <class 'pandas.core.arrays...  Represent a categorical va...  {'_dtype': 'CategoricalDty...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
3   CategoricalDtype  (categories=None, ordered:...  <class 'pandas.core.dtypes...  Type for categorical data ...  {'type': 'type[Categorical...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.dtypes...
4   CategoricalIndex  (data=None, categories=Non...  <class 'pandas.core.indexe...  Index based on an underlyi...  {'codes': 'np.ndarray', 'c...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.indexe...
5          DataFrame  (data=None, index: 'Axes |...  <class 'pandas.core.frame....  Two-dimensional, size-muta...  {'_accessors': 'set[str]',...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.frame....
6         DateOffset                           <NA>  <class 'pandas._libs.tslib...  Standard kind of date incr...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas._libs.tslib...
7      DatetimeIndex  (data=None, freq: 'Frequen...  <class 'pandas.core.indexe...  Immutable ndarray-like of ...  {'_data': 'DatetimeArray',...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.indexe...
8    DatetimeTZDtype  (unit: 'str_type | Datetim...  <class 'pandas.core.dtypes...  An ExtensionDtype for time...  {'type': 'type[Timestamp]'...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.dtypes...
9          ExcelFile  (path_or_buffer, engine: '...  <class 'pandas.io.excel._b...  Class for parsing tabular ...  {'_engines': 'Mapping[str,...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.io.excel._b...
10       ExcelWriter  (path: 'FilePath | WriteEx...  <class 'pandas.io.excel._b...  Class for writing DataFram...  {'_engine': 'str', '_suppo...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.io.excel._b...
11             Flags  (obj, *, allows_duplicate_...  <class 'pandas.core.flags....  Flags that apply to pandas...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.flags....
12      Float32Dtype                             ()  <class 'pandas.core.arrays...  An ExtensionDtype for floa...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
13      Float64Dtype                             ()  <class 'pandas.core.arrays...  An ExtensionDtype for floa...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
14           Grouper              (*args, **kwargs)  <class 'pandas.core.groupb...  A Grouper allows the user ...  {'sort': 'bool', 'dropna':...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.groupb...
15          HDFStore  (path, mode: 'str' = 'a', ...  <class 'pandas.io.pytables...  Dict-like IO interface for...  {'_handle': 'File | None',...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.io.pytables...
16             Index  (data=None, dtype=None, co...  <class 'pandas.core.indexe...  Immutable sequence used fo...  {'_typ': 'str', '_data': '...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.indexe...
17        IndexSlice                           <NA>  <pandas.core.indexing._Ind...  Create an object to more e...                           <NA>                           <NA>           <NA>  <pandas.core.indexing._Ind...
18        Int16Dtype                             ()  <class 'pandas.core.arrays...  An ExtensionDtype for int1...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
19        Int32Dtype                             ()  <class 'pandas.core.arrays...  An ExtensionDtype for int3...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
20        Int64Dtype                             ()  <class 'pandas.core.arrays...  An ExtensionDtype for int6...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
21         Int8Dtype                             ()  <class 'pandas.core.arrays...  An ExtensionDtype for int8...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.arrays...
22          Interval                           <NA>  <class 'pandas._libs.inter...  Immutable object implement...                             {}  c:\programdata\anaconda3\e...           <NA>  <class 'pandas._libs.inter...
23     IntervalDtype  (subtype=None, closed: 'st...  <class 'pandas.core.dtypes...  An ExtensionDtype for Inte...  {'kind': 'str_type', '_cac...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.dtypes...
24     IntervalIndex  (data, closed=None, dtype:...  <class 'pandas.core.indexe...  Immutable index of interva...  {'closed': 'IntervalClosed...  c:\programdata\anaconda3\e...           <NA>  <class 'pandas.core.indexe...

```